pip
===

`User list <http://groups.google.com/group/python-virtualenv>`_ |
`Dev list <http://groups.google.com/group/pypa-dev>`_ |
`Github <https://github.com/pypa/pip>`_ |
`PyPI <https://pypi.python.org/pypi/pip/>`_ |
User IRC: #pypa |
Dev IRC: #pypa-dev

The `PyPA recommended <https://packaging.python.org/en/latest/current/>`_ tool
for installing Python packages.

.. toctree::
   :maxdepth: 2

   quickstart
   installing
   user_guide
   reference/index
   development
   news
